@@ -16,7 +16,7 @@
  */
 
 .pragma library
-.import QtQuick 2.9 as Quick
+.import QtQuick 2.12 as Quick
 .import GCompris 1.0 as GCompris //for ApplicationInfo
 .import "qrc:/gcompris/src/core/core.js" as Core
 
@@ -481,6 +481,10 @@ function nextSubLevel() {
         // Stop having more words dropping once we have won
         items.wordDropTimer.stop();
         items.inputLocked = true;
+        // In case we have no audio voices for the locale, we directly play the bonus, else it is played at the end of the audio
+        if(items.audioVoices.files.length == 0) {
+            items.bonus.good("lion");
+        }
     } else {
         items.score.playWinAnimation();
     }
