@@ -10,7 +10,7 @@
  */
 
 .pragma library
-.import QtQuick 2.9 as Quick
+.import QtQuick 2.12 as Quick
 .import GCompris 1.0 as GCompris
 .import "qrc:/gcompris/src/core/core.js" as Core
 .import "qrc:/gcompris/src/activities/lang/lang_api.js" as Lang
@@ -62,6 +62,11 @@ function stop() {
 }
 
 function initLevel() {
+    // If clicking on previous/next level after winning, we prevent to skip the next word
+    if(items.winTimer.running) {
+        items.winTimer.stop();
+    }
+
     items.bar.level = currentLevel + 1;
     var currentLesson = lessons[currentLevel];
     wordList = Lang.getLessonWords(dataset, currentLesson);
@@ -109,8 +114,9 @@ function initLevel() {
 }
 
 function processKeyPress(text) {
-    if(items.remainingLife === 0 || items.bonus.isPlaying)
+    if(items.remainingLife === 0 || items.goodIcon.visible) {
         return
+    }
 
     text = text.toLocaleLowerCase()
 
