@@ -37,7 +37,7 @@ ApplicationInfo::ApplicationInfo(QObject *parent) :
     QObject(parent)
 {
 
-#if defined(Q_OS_ANDROID) || defined(Q_OS_IOS) || defined(Q_OS_BLACKBERRY) || defined(SAILFISHOS) || defined(UBUNTUTOUCH)
+#if defined(Q_OS_ANDROID) || defined(Q_OS_IOS) || defined(Q_OS_BLACKBERRY) || defined(UBUNTUTOUCH)
     m_isMobile = true;
 #else
     m_isMobile = false;
@@ -58,8 +58,6 @@ ApplicationInfo::ApplicationInfo(QObject *parent) :
     m_platform = Ios;
 #elif defined(Q_OS_BLACKBERRY)
     m_platform = Blackberry;
-#elif defined(SAILFISHOS)
-    m_platform = SailfishOS;
 #else // default is Linux
     m_platform = Linux;
 #endif
@@ -240,7 +238,7 @@ void ApplicationInfo::setBox2DInstalled(const QQmlEngine &engine)
       context->setContextObject(&myDataSet);
 
       QQmlComponent component(&engine);
-      component.setData("import QtQuick 2.0\nimport Box2D 2.0\nItem { }", QUrl());
+      component.setData("import QtQuick 2.12\nimport Box2D 2.0\nItem { }", QUrl());
       component.create(context);
       box2dInstalled = (component != nullptr);
     */
