@@ -19,6 +19,7 @@
 #include <QObject>
 #include <QLocale>
 #include <QQmlEngine>
+#include <QSslSocket>
 #include <QtGlobal>
 
 class QQuickWindow;
@@ -112,6 +113,11 @@ class ApplicationInfo : public QObject
      */
     Q_PROPERTY(QString QTVersion READ QTVersion CONSTANT)
 
+    /**
+     * OpenSSL version string (runtime).
+     */
+    Q_PROPERTY(QString OpenSSLVersion READ OpenSSLVersion CONSTANT)
+
     /**
      * Audio codec used for voices resources.
      *
@@ -144,8 +150,8 @@ class ApplicationInfo : public QObject
 
 public:
     /**
-	 * Known host platforms.
-	 */
+     * Known host platforms.
+     */
     enum Platform {
         Linux, /**< Linux (except Android) */
         Windows, /**< Windows */
@@ -153,7 +159,6 @@ public:
         Android, /**< Android */
         Ios, /**< IOS (not supported) */
         Blackberry, /**< Blackberry (not supported) */
-        SailfishOS, /**< SailfishOS */
         UbuntuTouchOS /**< UbuntuTouch OS */
     };
 
@@ -274,6 +279,7 @@ public:
     static QString GCVersion() { return VERSION; }
     static int GCVersionCode() { return VERSION_CODE; }
     static QString QTVersion() { return qVersion(); }
+    static QString OpenSSLVersion() { return QSslSocket::sslLibraryVersionString(); }
     static QString CompressedAudio() { return COMPRESSED_AUDIO; }
     static bool isDownloadAllowed() { return QString(DOWNLOAD_ALLOWED) == "ON"; }
     bool useOpenGL() const { return m_useOpenGL; }
