@@ -50,7 +50,7 @@ bool loadAndroidTranslation(QTranslator &translator, const QString &locale)
 /**
  * Checks if the locale is supported. Locale may have been removed because
  * translation progress was not enough or invalid language put in configuration.
-*/
+ */
 bool isSupportedLocale(const QString &locale)
 {
     bool isSupported = false;
@@ -131,7 +131,7 @@ int main(int argc, char *argv[])
     // the one we use (because appName is gcompris-qt, not gcompris)
     QGuiApplication::setDesktopFileName("org.kde.gcompris");
 
-    //add a variable to disable default fullscreen on Mac, see below..
+    // add a variable to disable default fullscreen on Mac, see below..
 #if defined(Q_OS_MAC)
     // Sandboxing on MacOSX as documented in:
     // https://doc.qt.io/qt-5/osx-deployment.html
@@ -189,12 +189,21 @@ int main(int argc, char *argv[])
     parser.addOption(clWithKioskMode);
 
     QCommandLineOption clSoftwareRenderer(QStringList() << "software-renderer",
-                                          QObject::tr("Use software renderer instead of openGL (slower but should run with any graphical card, needs Qt 5.8 minimum)."));
+                                          QObject::tr("Use software renderer instead of openGL (slower but should run with any graphical card)."));
     parser.addOption(clSoftwareRenderer);
     QCommandLineOption clOpenGLRenderer(QStringList() << "opengl-renderer",
                                         QObject::tr("Use openGL renderer instead of software (faster but crash potentially depending on your graphical card)."));
     parser.addOption(clOpenGLRenderer);
 
+    QCommandLineOption clStartOnActivity("launch",
+                                         QObject::tr("Specify the activity when starting GCompris."), "activity");
+    parser.addOption(clStartOnActivity);
+
+    QCommandLineOption clListActivities(QStringList() << "l"
+                                                      << "list-activities",
+                                        QObject::tr("Outputs all the available activities on the standard output."));
+    parser.addOption(clListActivities);
+
     parser.process(app);
 
     GComprisPlugin plugin;
@@ -287,17 +296,22 @@ int main(int argc, char *argv[])
 #endif
     }
 
+    // Start on specific activity
+    if (parser.isSet(clStartOnActivity)) {
+        QString startingActivity = parser.value(clStartOnActivity);
+        ActivityInfoTree::setStartingActivity(startingActivity);
+    }
+
     QQmlApplicationEngine engine(QUrl("qrc:/gcompris/src/core/main.qml"));
     QObject::connect(&engine, &QQmlApplicationEngine::quit, DownloadManager::getInstance(),
                      &DownloadManager::shutdown);
     // add import path for shipped qml modules:
-#ifdef SAILFISHOS
-    engine.addImportPath(QStringLiteral("%1/../share/%2/lib/qml")
-                             .arg(QCoreApplication::applicationDirPath())
-                             .arg(GCOMPRIS_APPLICATION_NAME));
-#else
     engine.addImportPath(QStringLiteral("%1/../lib/qml")
                              .arg(QCoreApplication::applicationDirPath()));
+
+#if __ANDROID__ && QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
+    // Find box2d
+    engine.addImportPath(QStringLiteral("assets:/"));
 #endif
 
     ApplicationInfo::getInstance()->setBox2DInstalled(engine);
@@ -305,7 +319,13 @@ int main(int argc, char *argv[])
     if (parser.isSet(exportActivitiesAsSQL)) {
         ActivityInfoTree *menuTree(qobject_cast<ActivityInfoTree *>(ActivityInfoTree::menuTreeProvider(&engine, nullptr)));
         menuTree->exportAsSQL();
-        exit(0);
+        return 0;
+    }
+
+    if (parser.isSet(clListActivities)) {
+        ActivityInfoTree *menuTree(qobject_cast<ActivityInfoTree *>(ActivityInfoTree::menuTreeProvider(&engine, nullptr)));
+        menuTree->listActivities();
+        return 0;
     }
 
     QObject *topLevel = engine.rootObjects().value(0);
